@@ -4,10 +4,10 @@
 class SimplipyError(Exception):
     """Define a base error."""
 
-    pass
+
+class InvalidCredentialsError(SimplipyError):
+    """Define an error related to invalid requests."""
 
 
 class RequestError(SimplipyError):
     """Define an error related to invalid requests."""
-
-    pass
